/**
 * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
 *
 * This library is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License as published by the Free
 * Software Foundation; either version 2.1 of the License, or (at your option)
 * any later version.
 *
 * This library is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more
 * details.
 */

package com.liferay.reading.time.model.impl;

import com.liferay.expando.kernel.model.ExpandoBridge;
import com.liferay.expando.kernel.util.ExpandoBridgeFactoryUtil;
import com.liferay.exportimport.kernel.lar.StagedModelType;
import com.liferay.portal.kernel.bean.AutoEscapeBeanHandler;
import com.liferay.portal.kernel.exception.NoSuchModelException;
import com.liferay.portal.kernel.exception.PortalException;
import com.liferay.portal.kernel.json.JSON;
import com.liferay.portal.kernel.model.CacheModel;
import com.liferay.portal.kernel.model.ContainerModel;
import com.liferay.portal.kernel.model.ModelWrapper;
import com.liferay.portal.kernel.model.TrashedModel;
import com.liferay.portal.kernel.model.impl.BaseModelImpl;
import com.liferay.portal.kernel.service.ServiceContext;
import com.liferay.portal.kernel.util.DateUtil;
import com.liferay.portal.kernel.util.GetterUtil;
import com.liferay.portal.kernel.util.PortalUtil;
import com.liferay.portal.kernel.util.ProxyUtil;
import com.liferay.portal.kernel.util.StringBundler;
import com.liferay.portal.kernel.util.Validator;
import com.liferay.portal.kernel.workflow.WorkflowConstants;
import com.liferay.reading.time.model.ReadingTimeEntry;
import com.liferay.reading.time.model.ReadingTimeEntryModel;
import com.liferay.reading.time.model.ReadingTimeEntrySoap;

import java.io.Serializable;

import java.lang.reflect.Constructor;
import java.lang.reflect.InvocationHandler;

import java.sql.Types;

import java.util.ArrayList;
import java.util.Collections;
import java.util.Date;
import java.util.HashMap;
import java.util.LinkedHashMap;
import java.util.List;
import java.util.Map;
import java.util.function.BiConsumer;
import java.util.function.Function;

/**
 * The base model implementation for the ReadingTimeEntry service. Represents a row in the &quot;ReadingTimeEntry&quot; database table, with each column mapped to a property of this class.
 *
 * <p>
 * This implementation and its corresponding interface <code>ReadingTimeEntryModel</code> exist only as a container for the default property accessors generated by ServiceBuilder. Helper methods and all application logic should be put in {@link ReadingTimeEntryImpl}.
 * </p>
 *
 * @author Brian Wing Shun Chan
 * @see ReadingTimeEntryImpl
 * @generated
 */
@JSON(strict = true)
public class ReadingTimeEntryModelImpl
	extends BaseModelImpl<ReadingTimeEntry> implements ReadingTimeEntryModel {

	/*
	 * NOTE FOR DEVELOPERS:
	 *
	 * Never modify or reference this class directly. All methods that expect a reading time entry model instance should use the <code>ReadingTimeEntry</code> interface instead.
	 */
	public static final String TABLE_NAME = "ReadingTimeEntry";

	public static final Object[][] TABLE_COLUMNS = {
		{"uuid_", Types.VARCHAR}, {"readingTimeEntryId", Types.BIGINT},
		{"groupId", Types.BIGINT}, {"companyId", Types.BIGINT},
		{"createDate", Types.TIMESTAMP}, {"modifiedDate", Types.TIMESTAMP},
		{"classNameId", Types.BIGINT}, {"classPK", Types.BIGINT},
		{"readingTime", Types.BIGINT}
	};

	public static final Map<String, Integer> TABLE_COLUMNS_MAP =
		new HashMap<String, Integer>();

	static {
		TABLE_COLUMNS_MAP.put("uuid_", Types.VARCHAR);
		TABLE_COLUMNS_MAP.put("readingTimeEntryId", Types.BIGINT);
		TABLE_COLUMNS_MAP.put("groupId", Types.BIGINT);
		TABLE_COLUMNS_MAP.put("companyId", Types.BIGINT);
		TABLE_COLUMNS_MAP.put("createDate", Types.TIMESTAMP);
		TABLE_COLUMNS_MAP.put("modifiedDate", Types.TIMESTAMP);
		TABLE_COLUMNS_MAP.put("classNameId", Types.BIGINT);
		TABLE_COLUMNS_MAP.put("classPK", Types.BIGINT);
		TABLE_COLUMNS_MAP.put("readingTime", Types.BIGINT);
	}

	public static final String TABLE_SQL_CREATE =
		"create table ReadingTimeEntry (uuid_ VARCHAR(75) null,readingTimeEntryId LONG not null primary key,groupId LONG,companyId LONG,createDate DATE null,modifiedDate DATE null,classNameId LONG,classPK LONG,readingTime LONG)";

	public static final String TABLE_SQL_DROP = "drop table ReadingTimeEntry";

	public static final String ORDER_BY_JPQL =
		" ORDER BY readingTimeEntry.createDate DESC";

	public static final String ORDER_BY_SQL =
		" ORDER BY ReadingTimeEntry.createDate DESC";

	public static final String DATA_SOURCE = "liferayDataSource";

	public static final String SESSION_FACTORY = "liferaySessionFactory";

	public static final String TX_MANAGER = "liferayTransactionManager";

	public static final boolean ENTITY_CACHE_ENABLED = GetterUtil.getBoolean(
		com.liferay.reading.time.service.util.ServiceProps.get(
			"value.object.entity.cache.enabled.com.liferay.reading.time.model.ReadingTimeEntry"),
		true);

	public static final boolean FINDER_CACHE_ENABLED = GetterUtil.getBoolean(
		com.liferay.reading.time.service.util.ServiceProps.get(
			"value.object.finder.cache.enabled.com.liferay.reading.time.model.ReadingTimeEntry"),
		true);

	public static final boolean COLUMN_BITMASK_ENABLED = GetterUtil.getBoolean(
		com.liferay.reading.time.service.util.ServiceProps.get(
			"value.object.column.bitmask.enabled.com.liferay.reading.time.model.ReadingTimeEntry"),
		true);

	public static final long CLASSNAMEID_COLUMN_BITMASK = 1L;

	public static final long CLASSPK_COLUMN_BITMASK = 2L;

	public static final long COMPANYID_COLUMN_BITMASK = 4L;

	public static final long GROUPID_COLUMN_BITMASK = 8L;

	public static final long UUID_COLUMN_BITMASK = 16L;

	public static final long CREATEDATE_COLUMN_BITMASK = 32L;

	/**
	 * Converts the soap model instance into a normal model instance.
	 *
	 * @param soapModel the soap model instance to convert
	 * @return the normal model instance
	 */
	public static ReadingTimeEntry toModel(ReadingTimeEntrySoap soapModel) {
		if (soapModel == null) {
			return null;
		}

		ReadingTimeEntry model = new ReadingTimeEntryImpl();

		model.setUuid(soapModel.getUuid());
		model.setReadingTimeEntryId(soapModel.getReadingTimeEntryId());
		model.setGroupId(soapModel.getGroupId());
		model.setCompanyId(soapModel.getCompanyId());
		model.setCreateDate(soapModel.getCreateDate());
		model.setModifiedDate(soapModel.getModifiedDate());
		model.setClassNameId(soapModel.getClassNameId());
		model.setClassPK(soapModel.getClassPK());
		model.setReadingTime(soapModel.getReadingTime());

		return model;
	}

	/**
	 * Converts the soap model instances into normal model instances.
	 *
	 * @param soapModels the soap model instances to convert
	 * @return the normal model instances
	 */
	public static List<ReadingTimeEntry> toModels(
		ReadingTimeEntrySoap[] soapModels) {

		if (soapModels == null) {
			return null;
		}

		List<ReadingTimeEntry> models = new ArrayList<ReadingTimeEntry>(
			soapModels.length);

		for (ReadingTimeEntrySoap soapModel : soapModels) {
			models.add(toModel(soapModel));
		}

		return models;
	}

	public static final long LOCK_EXPIRATION_TIME = GetterUtil.getLong(
		com.liferay.reading.time.service.util.ServiceProps.get(
			"lock.expiration.time.com.liferay.reading.time.model.ReadingTimeEntry"));

	public ReadingTimeEntryModelImpl() {
	}

	@Override
	public long getPrimaryKey() {
		return _readingTimeEntryId;
	}

	@Override
	public void setPrimaryKey(long primaryKey) {
		setReadingTimeEntryId(primaryKey);
	}

	@Override
	public Serializable getPrimaryKeyObj() {
		return _readingTimeEntryId;
	}

	@Override
	public void setPrimaryKeyObj(Serializable primaryKeyObj) {
		setPrimaryKey(((Long)primaryKeyObj).longValue());
	}

	@Override
	public Class<?> getModelClass() {
		return ReadingTimeEntry.class;
	}

	@Override
	public String getModelClassName() {
		return ReadingTimeEntry.class.getName();
	}

	@Override
	public Map<String, Object> getModelAttributes() {
		Map<String, Object> attributes = new HashMap<String, Object>();

		Map<String, Function<ReadingTimeEntry, Object>>
			attributeGetterFunctions = getAttributeGetterFunctions();

		for (Map.Entry<String, Function<ReadingTimeEntry, Object>> entry :
				attributeGetterFunctions.entrySet()) {

			String attributeName = entry.getKey();
			Function<ReadingTimeEntry, Object> attributeGetterFunction =
				entry.getValue();

			attributes.put(
				attributeName,
				attributeGetterFunction.apply((ReadingTimeEntry)this));
		}

		attributes.put("entityCacheEnabled", isEntityCacheEnabled());
		attributes.put("finderCacheEnabled", isFinderCacheEnabled());

		return attributes;
	}

	@Override
	public void setModelAttributes(Map<String, Object> attributes) {
		Map<String, BiConsumer<ReadingTimeEntry, Object>>
			attributeSetterBiConsumers = getAttributeSetterBiConsumers();

		for (Map.Entry<String, Object> entry : attributes.entrySet()) {
			String attributeName = entry.getKey();

			BiConsumer<ReadingTimeEntry, Object> attributeSetterBiConsumer =
				attributeSetterBiConsumers.get(attributeName);

			if (attributeSetterBiConsumer != null) {
				attributeSetterBiConsumer.accept(
					(ReadingTimeEntry)this, entry.getValue());
			}
		}
	}

	public Map<String, Function<ReadingTimeEntry, Object>>
		getAttributeGetterFunctions() {

		return _attributeGetterFunctions;
	}

	public Map<String, BiConsumer<ReadingTimeEntry, Object>>
		getAttributeSetterBiConsumers() {

		return _attributeSetterBiConsumers;
	}

	private static Function<InvocationHandler, ReadingTimeEntry>
		_getProxyProviderFunction() {

		Class<?> proxyClass = ProxyUtil.getProxyClass(
			ReadingTimeEntry.class.getClassLoader(), ReadingTimeEntry.class,
			ModelWrapper.class);

		try {
			Constructor<ReadingTimeEntry> constructor =
				(Constructor<ReadingTimeEntry>)proxyClass.getConstructor(
					InvocationHandler.class);

			return invocationHandler -> {
				try {
					return constructor.newInstance(invocationHandler);
				}
				catch (ReflectiveOperationException roe) {
					throw new InternalError(roe);
				}
			};
		}
		catch (NoSuchMethodException nsme) {
			throw new InternalError(nsme);
		}
	}

	private static final Map<String, Function<ReadingTimeEntry, Object>>
		_attributeGetterFunctions;
	private static final Map<String, BiConsumer<ReadingTimeEntry, Object>>
		_attributeSetterBiConsumers;

	static {
		Map<String, Function<ReadingTimeEntry, Object>>
			attributeGetterFunctions =
				new LinkedHashMap<String, Function<ReadingTimeEntry, Object>>();
		Map<String, BiConsumer<ReadingTimeEntry, ?>>
			attributeSetterBiConsumers =
				new LinkedHashMap<String, BiConsumer<ReadingTimeEntry, ?>>();

		attributeGetterFunctions.put(
			"uuid",
			new Function<ReadingTimeEntry, Object>() {

				@Override
				public Object apply(ReadingTimeEntry readingTimeEntry) {
					return readingTimeEntry.getUuid();
				}

			});
		attributeSetterBiConsumers.put(
			"uuid",
			new BiConsumer<ReadingTimeEntry, Object>() {

				@Override
				public void accept(
					ReadingTimeEntry readingTimeEntry, Object uuidObject) {

					readingTimeEntry.setUuid((String)uuidObject);
				}

			});
		attributeGetterFunctions.put(
			"readingTimeEntryId",
			new Function<ReadingTimeEntry, Object>() {

				@Override
				public Object apply(ReadingTimeEntry readingTimeEntry) {
					return readingTimeEntry.getReadingTimeEntryId();
				}

			});
		attributeSetterBiConsumers.put(
			"readingTimeEntryId",
			new BiConsumer<ReadingTimeEntry, Object>() {

				@Override
				public void accept(
					ReadingTimeEntry readingTimeEntry,
					Object readingTimeEntryIdObject) {

					readingTimeEntry.setReadingTimeEntryId(
						(Long)readingTimeEntryIdObject);
				}

			});
		attributeGetterFunctions.put(
			"groupId",
			new Function<ReadingTimeEntry, Object>() {

				@Override
				public Object apply(ReadingTimeEntry readingTimeEntry) {
					return readingTimeEntry.getGroupId();
				}

			});
		attributeSetterBiConsumers.put(
			"groupId",
			new BiConsumer<ReadingTimeEntry, Object>() {

				@Override
				public void accept(
					ReadingTimeEntry readingTimeEntry, Object groupIdObject) {

					readingTimeEntry.setGroupId((Long)groupIdObject);
				}

			});
		attributeGetterFunctions.put(
			"companyId",
			new Function<ReadingTimeEntry, Object>() {

				@Override
				public Object apply(ReadingTimeEntry readingTimeEntry) {
					return readingTimeEntry.getCompanyId();
				}

			});
		attributeSetterBiConsumers.put(
			"companyId",
			new BiConsumer<ReadingTimeEntry, Object>() {

				@Override
				public void accept(
					ReadingTimeEntry readingTimeEntry, Object companyIdObject) {

					readingTimeEntry.setCompanyId((Long)companyIdObject);
				}

			});
		attributeGetterFunctions.put(
			"createDate",
			new Function<ReadingTimeEntry, Object>() {

				@Override
				public Object apply(ReadingTimeEntry readingTimeEntry) {
					return readingTimeEntry.getCreateDate();
				}

			});
		attributeSetterBiConsumers.put(
			"createDate",
			new BiConsumer<ReadingTimeEntry, Object>() {

				@Override
				public void accept(
					ReadingTimeEntry readingTimeEntry,
					Object createDateObject) {

					readingTimeEntry.setCreateDate((Date)createDateObject);
				}

			});
		attributeGetterFunctions.put(
			"modifiedDate",
			new Function<ReadingTimeEntry, Object>() {

				@Override
				public Object apply(ReadingTimeEntry readingTimeEntry) {
					return readingTimeEntry.getModifiedDate();
				}

			});
		attributeSetterBiConsumers.put(
			"modifiedDate",
			new BiConsumer<ReadingTimeEntry, Object>() {

				@Override
				public void accept(
					ReadingTimeEntry readingTimeEntry,
					Object modifiedDateObject) {

					readingTimeEntry.setModifiedDate((Date)modifiedDateObject);
				}

			});
		attributeGetterFunctions.put(
			"classNameId",
			new Function<ReadingTimeEntry, Object>() {

				@Override
				public Object apply(ReadingTimeEntry readingTimeEntry) {
					return readingTimeEntry.getClassNameId();
				}

			});
		attributeSetterBiConsumers.put(
			"classNameId",
			new BiConsumer<ReadingTimeEntry, Object>() {

				@Override
				public void accept(
					ReadingTimeEntry readingTimeEntry,
					Object classNameIdObject) {

					readingTimeEntry.setClassNameId((Long)classNameIdObject);
				}

			});
		attributeGetterFunctions.put(
			"classPK",
			new Function<ReadingTimeEntry, Object>() {

				@Override
				public Object apply(ReadingTimeEntry readingTimeEntry) {
					return readingTimeEntry.getClassPK();
				}

			});
		attributeSetterBiConsumers.put(
			"classPK",
			new BiConsumer<ReadingTimeEntry, Object>() {

				@Override
				public void accept(
					ReadingTimeEntry readingTimeEntry, Object classPKObject) {

					readingTimeEntry.setClassPK((Long)classPKObject);
				}

			});
		attributeGetterFunctions.put(
			"readingTime",
			new Function<ReadingTimeEntry, Object>() {

				@Override
				public Object apply(ReadingTimeEntry readingTimeEntry) {
					return readingTimeEntry.getReadingTime();
				}

			});
		attributeSetterBiConsumers.put(
			"readingTime",
			new BiConsumer<ReadingTimeEntry, Object>() {

				@Override
				public void accept(
					ReadingTimeEntry readingTimeEntry,
					Object readingTimeObject) {

					readingTimeEntry.setReadingTime((Long)readingTimeObject);
				}

			});

		_attributeGetterFunctions = Collections.unmodifiableMap(
			attributeGetterFunctions);
		_attributeSetterBiConsumers = Collections.unmodifiableMap(
			(Map)attributeSetterBiConsumers);
	}

	@JSON
	@Override
	public String getUuid() {
		if (_uuid == null) {
			return "";
		}
		else {
			return _uuid;
		}
	}

	@Override
	public void setUuid(String uuid) {
		_columnBitmask |= UUID_COLUMN_BITMASK;

		if (_originalUuid == null) {
			_originalUuid = _uuid;
		}

		_uuid = uuid;
	}

	public String getOriginalUuid() {
		return GetterUtil.getString(_originalUuid);
	}

	@JSON
	@Override
	public long getReadingTimeEntryId() {
		return _readingTimeEntryId;
	}

	@Override
	public void setReadingTimeEntryId(long readingTimeEntryId) {
		_readingTimeEntryId = readingTimeEntryId;
	}

	@JSON
	@Override
	public long getGroupId() {
		return _groupId;
	}

	@Override
	public void setGroupId(long groupId) {
		_columnBitmask |= GROUPID_COLUMN_BITMASK;

		if (!_setOriginalGroupId) {
			_setOriginalGroupId = true;

			_originalGroupId = _groupId;
		}

		_groupId = groupId;
	}

	public long getOriginalGroupId() {
		return _originalGroupId;
	}

	@JSON
	@Override
	public long getCompanyId() {
		return _companyId;
	}

	@Override
	public void setCompanyId(long companyId) {
		_columnBitmask |= COMPANYID_COLUMN_BITMASK;

		if (!_setOriginalCompanyId) {
			_setOriginalCompanyId = true;

			_originalCompanyId = _companyId;
		}

		_companyId = companyId;
	}

	public long getOriginalCompanyId() {
		return _originalCompanyId;
	}

	@JSON
	@Override
	public Date getCreateDate() {
		return _createDate;
	}

	@Override
	public void setCreateDate(Date createDate) {
		_columnBitmask = -1L;

		_createDate = createDate;
	}

	@JSON
	@Override
	public Date getModifiedDate() {
		return _modifiedDate;
	}

	public boolean hasSetModifiedDate() {
		return _setModifiedDate;
	}

	@Override
	public void setModifiedDate(Date modifiedDate) {
		_setModifiedDate = true;

		_modifiedDate = modifiedDate;
	}

	@Override
	public String getClassName() {
		if (getClassNameId() <= 0) {
			return "";
		}

		return PortalUtil.getClassName(getClassNameId());
	}

	@Override
	public void setClassName(String className) {
		long classNameId = 0;

		if (Validator.isNotNull(className)) {
			classNameId = PortalUtil.getClassNameId(className);
		}

		setClassNameId(classNameId);
	}

	@JSON
	@Override
	public long getClassNameId() {
		return _classNameId;
	}

	@Override
	public void setClassNameId(long classNameId) {
		_columnBitmask |= CLASSNAMEID_COLUMN_BITMASK;

		if (!_setOriginalClassNameId) {
			_setOriginalClassNameId = true;

			_originalClassNameId = _classNameId;
		}

		_classNameId = classNameId;
	}

	public long getOriginalClassNameId() {
		return _originalClassNameId;
	}

	@JSON
	@Override
	public long getClassPK() {
		return _classPK;
	}

	@Override
	public void setClassPK(long classPK) {
		_columnBitmask |= CLASSPK_COLUMN_BITMASK;

		if (!_setOriginalClassPK) {
			_setOriginalClassPK = true;

			_originalClassPK = _classPK;
		}

		_classPK = classPK;
	}

	public long getOriginalClassPK() {
		return _originalClassPK;
	}

	@JSON
	@Override
	public long getReadingTime() {
		return _readingTime;
	}

	@Override
	public void setReadingTime(long readingTime) {
		_readingTime = readingTime;
	}

	@Override
	public StagedModelType getStagedModelType() {
		return new StagedModelType(
			PortalUtil.getClassNameId(ReadingTimeEntry.class.getName()),
			getClassNameId());
	}

	@Override
	public int getStatus() {
		return 0;
	}

	@Override
	public com.liferay.trash.kernel.model.TrashEntry getTrashEntry()
		throws PortalException {

		if (!isInTrash()) {
			return null;
		}

		com.liferay.trash.kernel.model.TrashEntry trashEntry =
			com.liferay.trash.kernel.service.TrashEntryLocalServiceUtil.
				fetchEntry(getModelClassName(), getTrashEntryClassPK());

		if (trashEntry != null) {
			return trashEntry;
		}

		com.liferay.portal.kernel.trash.TrashHandler trashHandler =
			getTrashHandler();

		if (Validator.isNotNull(
				trashHandler.getContainerModelClassName(getPrimaryKey()))) {

			ContainerModel containerModel = null;

			try {
				containerModel = trashHandler.getParentContainerModel(this);
			}
			catch (NoSuchModelException nsme) {
				return null;
			}

			while (containerModel != null) {
				if (containerModel instanceof TrashedModel) {
					TrashedModel trashedModel = (TrashedModel)containerModel;

					return trashedModel.getTrashEntry();
				}

				trashHandler =
					com.liferay.portal.kernel.trash.TrashHandlerRegistryUtil.
						getTrashHandler(
							trashHandler.getContainerModelClassName(
								containerModel.getContainerModelId()));

				if (trashHandler == null) {
					return null;
				}

				containerModel = trashHandler.getContainerModel(
					containerModel.getParentContainerModelId());
			}
		}

		return null;
	}

	@Override
	public long getTrashEntryClassPK() {
		return getPrimaryKey();
	}

	/**
	 * @deprecated As of Judson (7.1.x), with no direct replacement
	 */
	@Deprecated
	@Override
	public com.liferay.portal.kernel.trash.TrashHandler getTrashHandler() {
		return com.liferay.portal.kernel.trash.TrashHandlerRegistryUtil.
			getTrashHandler(getModelClassName());
	}

	@Override
	public boolean isInTrash() {
		if (getStatus() == WorkflowConstants.STATUS_IN_TRASH) {
			return true;
		}
		else {
			return false;
		}
	}

	@Override
	public boolean isInTrashContainer() {
		com.liferay.portal.kernel.trash.TrashHandler trashHandler =
			getTrashHandler();

		if ((trashHandler == null) ||
			Validator.isNull(
				trashHandler.getContainerModelClassName(getPrimaryKey()))) {

			return false;
		}

		try {
			ContainerModel containerModel =
				trashHandler.getParentContainerModel(this);

			if (containerModel == null) {
				return false;
			}

			if (containerModel instanceof TrashedModel) {
				return ((TrashedModel)containerModel).isInTrash();
			}
		}
		catch (Exception e) {
		}

		return false;
	}

	@Override
	public boolean isInTrashExplicitly() {
		if (!isInTrash()) {
			return false;
		}

		com.liferay.trash.kernel.model.TrashEntry trashEntry =
			com.liferay.trash.kernel.service.TrashEntryLocalServiceUtil.
				fetchEntry(getModelClassName(), getTrashEntryClassPK());

		if (trashEntry != null) {
			return true;
		}

		return false;
	}

	@Override
	public boolean isInTrashImplicitly() {
		if (!isInTrash()) {
			return false;
		}

		com.liferay.trash.kernel.model.TrashEntry trashEntry =
			com.liferay.trash.kernel.service.TrashEntryLocalServiceUtil.
				fetchEntry(getModelClassName(), getTrashEntryClassPK());

		if (trashEntry != null) {
			return false;
		}

		return true;
	}

	public long getColumnBitmask() {
		return _columnBitmask;
	}

	@Override
	public ExpandoBridge getExpandoBridge() {
		return ExpandoBridgeFactoryUtil.getExpandoBridge(
			getCompanyId(), ReadingTimeEntry.class.getName(), getPrimaryKey());
	}

	@Override
	public void setExpandoBridgeAttributes(ServiceContext serviceContext) {
		ExpandoBridge expandoBridge = getExpandoBridge();

		expandoBridge.setAttributes(serviceContext);
	}

	@Override
	public ReadingTimeEntry toEscapedModel() {
		if (_escapedModel == null) {
			Function<InvocationHandler, ReadingTimeEntry>
				escapedModelProxyProviderFunction =
					EscapedModelProxyProviderFunctionHolder.
						_escapedModelProxyProviderFunction;

			_escapedModel = escapedModelProxyProviderFunction.apply(
				new AutoEscapeBeanHandler(this));
		}

		return _escapedModel;
	}

	@Override
	public Object clone() {
		ReadingTimeEntryImpl readingTimeEntryImpl = new ReadingTimeEntryImpl();

		readingTimeEntryImpl.setUuid(getUuid());
		readingTimeEntryImpl.setReadingTimeEntryId(getReadingTimeEntryId());
		readingTimeEntryImpl.setGroupId(getGroupId());
		readingTimeEntryImpl.setCompanyId(getCompanyId());
		readingTimeEntryImpl.setCreateDate(getCreateDate());
		readingTimeEntryImpl.setModifiedDate(getModifiedDate());
		readingTimeEntryImpl.setClassNameId(getClassNameId());
		readingTimeEntryImpl.setClassPK(getClassPK());
		readingTimeEntryImpl.setReadingTime(getReadingTime());

		readingTimeEntryImpl.resetOriginalValues();

		return readingTimeEntryImpl;
	}

	@Override
	public int compareTo(ReadingTimeEntry readingTimeEntry) {
		int value = 0;

		value = DateUtil.compareTo(
			getCreateDate(), readingTimeEntry.getCreateDate());

		value = value * -1;

		if (value != 0) {
			return value;
		}

		return 0;
	}

	@Override
	public boolean equals(Object obj) {
		if (this == obj) {
			return true;
		}

		if (!(obj instanceof ReadingTimeEntry)) {
			return false;
		}

		ReadingTimeEntry readingTimeEntry = (ReadingTimeEntry)obj;

		long primaryKey = readingTimeEntry.getPrimaryKey();

		if (getPrimaryKey() == primaryKey) {
			return true;
		}
		else {
			return false;
		}
	}

	@Override
	public int hashCode() {
		return (int)getPrimaryKey();
	}

	@Override
	public boolean isEntityCacheEnabled() {
		return ENTITY_CACHE_ENABLED;
	}

	@Override
	public boolean isFinderCacheEnabled() {
		return FINDER_CACHE_ENABLED;
	}

	@Override
	public void resetOriginalValues() {
		ReadingTimeEntryModelImpl readingTimeEntryModelImpl = this;

		readingTimeEntryModelImpl._originalUuid =
			readingTimeEntryModelImpl._uuid;

		readingTimeEntryModelImpl._originalGroupId =
			readingTimeEntryModelImpl._groupId;

		readingTimeEntryModelImpl._setOriginalGroupId = false;

		readingTimeEntryModelImpl._originalCompanyId =
			readingTimeEntryModelImpl._companyId;

		readingTimeEntryModelImpl._setOriginalCompanyId = false;

		readingTimeEntryModelImpl._setModifiedDate = false;

		readingTimeEntryModelImpl._originalClassNameId =
			readingTimeEntryModelImpl._classNameId;

		readingTimeEntryModelImpl._setOriginalClassNameId = false;

		readingTimeEntryModelImpl._originalClassPK =
			readingTimeEntryModelImpl._classPK;

		readingTimeEntryModelImpl._setOriginalClassPK = false;

		readingTimeEntryModelImpl._columnBitmask = 0;
	}

	@Override
	public CacheModel<ReadingTimeEntry> toCacheModel() {
		ReadingTimeEntryCacheModel readingTimeEntryCacheModel =
			new ReadingTimeEntryCacheModel();

		readingTimeEntryCacheModel.uuid = getUuid();

		String uuid = readingTimeEntryCacheModel.uuid;

		if ((uuid != null) && (uuid.length() == 0)) {
			readingTimeEntryCacheModel.uuid = null;
		}

		readingTimeEntryCacheModel.readingTimeEntryId = getReadingTimeEntryId();

		readingTimeEntryCacheModel.groupId = getGroupId();

		readingTimeEntryCacheModel.companyId = getCompanyId();

		Date createDate = getCreateDate();

		if (createDate != null) {
			readingTimeEntryCacheModel.createDate = createDate.getTime();
		}
		else {
			readingTimeEntryCacheModel.createDate = Long.MIN_VALUE;
		}

		Date modifiedDate = getModifiedDate();

		if (modifiedDate != null) {
			readingTimeEntryCacheModel.modifiedDate = modifiedDate.getTime();
		}
		else {
			readingTimeEntryCacheModel.modifiedDate = Long.MIN_VALUE;
		}

		readingTimeEntryCacheModel.classNameId = getClassNameId();

		readingTimeEntryCacheModel.classPK = getClassPK();

		readingTimeEntryCacheModel.readingTime = getReadingTime();

		return readingTimeEntryCacheModel;
	}

	@Override
	public String toString() {
		Map<String, Function<ReadingTimeEntry, Object>>
			attributeGetterFunctions = getAttributeGetterFunctions();

		StringBundler sb = new StringBundler(
			4 * attributeGetterFunctions.size() + 2);

		sb.append("{");

		for (Map.Entry<String, Function<ReadingTimeEntry, Object>> entry :
				attributeGetterFunctions.entrySet()) {

			String attributeName = entry.getKey();
			Function<ReadingTimeEntry, Object> attributeGetterFunction =
				entry.getValue();

			sb.append(attributeName);
			sb.append("=");
			sb.append(attributeGetterFunction.apply((ReadingTimeEntry)this));
			sb.append(", ");
		}

		if (sb.index() > 1) {
			sb.setIndex(sb.index() - 1);
		}

		sb.append("}");

		return sb.toString();
	}

	@Override
	public String toXmlString() {
		Map<String, Function<ReadingTimeEntry, Object>>
			attributeGetterFunctions = getAttributeGetterFunctions();

		StringBundler sb = new StringBundler(
			5 * attributeGetterFunctions.size() + 4);

		sb.append("<model><model-name>");
		sb.append(getModelClassName());
		sb.append("</model-name>");

		for (Map.Entry<String, Function<ReadingTimeEntry, Object>> entry :
				attributeGetterFunctions.entrySet()) {

			String attributeName = entry.getKey();
			Function<ReadingTimeEntry, Object> attributeGetterFunction =
				entry.getValue();

			sb.append("<column><column-name>");
			sb.append(attributeName);
			sb.append("</column-name><column-value><![CDATA[");
			sb.append(attributeGetterFunction.apply((ReadingTimeEntry)this));
			sb.append("]]></column-value></column>");
		}

		sb.append("</model>");

		return sb.toString();
	}

	private static class EscapedModelProxyProviderFunctionHolder {

		private static final Function<InvocationHandler, ReadingTimeEntry>
			_escapedModelProxyProviderFunction = _getProxyProviderFunction();

	}

	private String _uuid;
	private String _originalUuid;
	private long _readingTimeEntryId;
	private long _groupId;
	private long _originalGroupId;
	private boolean _setOriginalGroupId;
	private long _companyId;
	private long _originalCompanyId;
	private boolean _setOriginalCompanyId;
	private Date _createDate;
	private Date _modifiedDate;
	private boolean _setModifiedDate;
	private long _classNameId;
	private long _originalClassNameId;
	private boolean _setOriginalClassNameId;
	private long _classPK;
	private long _originalClassPK;
	private boolean _setOriginalClassPK;
	private long _readingTime;
	private long _columnBitmask;
	private ReadingTimeEntry _escapedModel;

}